@@ -4,7 +4,7 @@ use std::hash::Hash;
 
 use async_trait::async_trait;
 use serde::de::DeserializeOwned;
-use serde::Serialize;
+use serde::{Serialize, Serializer, Deserialize, Deserializer};
 use serde_json::{Map, Value};
 
 use crate::core::convert::{ResultCodec, StmtConvert};
@@ -19,6 +19,8 @@ use crate::rbatis::Rbatis;
 use crate::sql::rule::SqlRule;
 use crate::utils::string_util::to_snake_name;
 use crate::wrapper::Wrapper;
+use std::marker::PhantomData;
+use std::ops::{Deref, DerefMut};
 
 /// DataBase Table Model trait
 ///
@@ -254,12 +256,12 @@ pub trait CRUD {
             T: CRUDTable, C: Serialize + Send + Sync;
 
     /// update_by_wrapper
-    /// skips: use &["id","null"] will skip id column and null value param
+    /// skips: use &[Skip::Null] will skip id column and null value param
     async fn update_by_wrapper<T>(
         &self,
         table: &mut T,
         w: &Wrapper,
-        skips: &[&str],
+        skips: &[Skip],
     ) -> Result<u64>
         where
             T: CRUDTable;
@@ -543,12 +545,12 @@ pub trait CRUDMut: ExecutorMut {
     }
 
     /// update_by_wrapper
-    /// skips: use &["id","null"] will skip id column and null value param
+    /// skips: use &[Skip::Value(&serde_json::Value::Null), Skip::Column("id"), Skip::Column(column)] will skip id column and null value param
     async fn update_by_wrapper<T>(
         &mut self,
         table: &mut T,
         w: &Wrapper,
-        skips: &[&str],
+        skips: &[Skip],
     ) -> Result<u64>
         where
             T: CRUDTable,
@@ -570,19 +572,19 @@ pub trait CRUDMut: ExecutorMut {
         }
         let null = serde_json::Value::Null;
         let mut sets = String::new();
-        let mut skip_null_value = false;
-        for x in skips {
-            if "null".eq(*x) {
-                skip_null_value = true;
-            }
-        }
 
         for column in columns_vec {
             //filter
             let mut is_continue = false;
             for x in skips {
-                if column.eq(*x) {
-                    is_continue = true;
+                match x {
+                    Skip::Column(skip_column) => {
+                        if skip_column.eq(&column) {
+                            is_continue = true;
+                            break;
+                        }
+                    }
+                    _ => {}
                 }
             }
             if is_continue {
@@ -590,10 +592,21 @@ pub trait CRUDMut: ExecutorMut {
             }
             let mut v = map.get(column).unwrap_or_else(|| &null).clone();
             //filter null
-            if skip_null_value && v.is_null() {
+            let is_null = v.is_null();
+            for x in skips {
+                match x {
+                    Skip::Value(skip_value) => {
+                        if (*skip_value).eq(&v) {
+                            is_continue = true;
+                            break;
+                        }
+                    }
+                    _ => {}
+                }
+            }
+            if is_continue {
                 continue;
             }
-
             let mut data = String::new();
             driver_type.stmt_convert(args.len(), &mut data);
             T::do_format_column(
@@ -690,7 +703,7 @@ pub trait CRUDMut: ExecutorMut {
             &rb
                 .new_wrapper_table::<T>()
                 .eq(column, value),
-            &["null", "id", column],
+            &[Skip::Value(&Value::Null), Skip::Column("id"), Skip::Column(column)],
         )
             .await
     }
@@ -758,7 +771,7 @@ pub trait CRUDMut: ExecutorMut {
         where
             T: CRUDTable, C: Serialize + Send + Sync,
     {
-        if column_values.is_empty(){
+        if column_values.is_empty() {
             return Ok(vec![]);
         }
         let w = self.get_rbatis().new_wrapper_table::<T>().in_array(&column, column_values);
@@ -898,8 +911,8 @@ impl CRUD for Rbatis {
     }
 
     /// update_by_wrapper
-    /// skips: use &["id","null"] will skip id column and null value param
-    async fn update_by_wrapper<T>(&self, table: &mut T, w: &Wrapper, skips: &[&str]) -> Result<u64> where
+    /// skips: use &[Skip::Value(&serde_json::Value::Null), Skip::Column("id"), Skip::Column(column)] will skip id column and null value param
+    async fn update_by_wrapper<T>(&self, table: &mut T, w: &Wrapper, skips: &[Skip]) -> Result<u64> where
         T: CRUDTable {
         let mut conn = self.acquire().await?;
         conn.update_by_wrapper(table, w, skips).await
@@ -975,4 +988,100 @@ impl CRUD for Rbatis {
         let mut conn = self.acquire().await?;
         conn.fetch_page(sql, args, page_request).await
     }
-}
\ No newline at end of file
+}
+
+
+/// choose skip type
+pub enum Skip<'a> {
+    ///skip column
+    Column(&'a str),
+    ///skip serde json value ref
+    Value(&'a serde_json::Value),
+}
+
+
+pub trait TableColumnProvider: Send + Sync {
+    fn table_name() -> String;
+    fn table_columns() -> String;
+}
+
+/// DynColumn , can custom insert,update column
+pub struct DynTableColumn<T: CRUDTable, P: TableColumnProvider> {
+    pub inner: T,
+    pub p: PhantomData<P>,
+}
+
+impl<T, P> Serialize for DynTableColumn<T, P> where T: CRUDTable, P: TableColumnProvider {
+    fn serialize<S>(&self, serializer: S) -> std::result::Result<<S as Serializer>::Ok, <S as Serializer>::Error> where
+        S: Serializer {
+        T::serialize(&self.inner, serializer)
+    }
+}
+
+impl<'de, T, P> Deserialize<'de> for DynTableColumn<T, P> where T: CRUDTable, P: TableColumnProvider {
+    fn deserialize<D>(deserializer: D) -> std::result::Result<Self, <D as Deserializer<'de>>::Error> where
+        D: Deserializer<'de> {
+        let result = T::deserialize(deserializer)?;
+        return Ok(DynTableColumn {
+            inner: result,
+            p: Default::default(),
+        });
+    }
+}
+
+impl<T, P> Deref for DynTableColumn<T, P> where T: CRUDTable, P: TableColumnProvider {
+    type Target = T;
+
+    fn deref(&self) -> &Self::Target {
+        &self.inner
+    }
+}
+
+impl<T, P> DerefMut for DynTableColumn<T, P> where T: CRUDTable, P: TableColumnProvider {
+    fn deref_mut(&mut self) -> &mut Self::Target {
+        &mut self.inner
+    }
+}
+
+impl<T, P> CRUDTable for DynTableColumn<T, P> where T: CRUDTable, P: TableColumnProvider {
+    /// is enable use plugin
+    fn is_use_plugin(plugin_name: &str) -> bool { T::is_use_plugin(plugin_name) }
+
+    fn table_name() -> String {
+        P::table_name()
+    }
+
+    fn table_columns() -> String {
+        P::table_columns()
+    }
+
+    ///format column
+    fn do_format_column(driver_type: &DriverType, column: &str, data: &mut String) {
+        T::do_format_column(driver_type, column, data)
+    }
+
+    ///return (columns_sql,columns_values_sql,args)
+    fn make_value_sql_arg(
+        &self,
+        db_type: &DriverType,
+        index: &mut usize,
+    ) -> Result<(String, String, Vec<serde_json::Value>)> {
+        T::make_value_sql_arg(self, db_type, index)
+    }
+
+    /// return cast chain
+    /// column:format_str
+    /// for example: HashMap<"id",|arg|“{}::uuid”.to_string()>
+    fn formats(
+        driver_type: &crate::core::db::DriverType,
+    ) -> HashMap<String, fn(arg: &str) -> String> {
+        T::formats(driver_type)
+    }
+
+
+    /// return table column value
+    /// If a macro is used, the method is overridden by the macro
+    fn get(&self, column: &str) -> serde_json::Value {
+        T::get(self, column)
+    }
+}
